==> 10.0.tar.gz: decision-webui-dcm/src/modules/pages/connection/list/list_item/list_item.ts <==
import { shortcut, store } from '@core/core';
import './list_item.less';
import { ListItemModel } from './list_item.model';
import { PAGE_INDEX } from '@constants/constant';
import { hasRegistered } from '../list.service';
import { connectionCanEdit, getTextByDatabaseType, getChartLength } from '../../../../app.service';
import { testConnection } from '../../../maintain/forms/form.server';
import { DownListCombo, Label, SignEditor } from '@fui/core';

@shortcut()
@store(ListItemModel)
export class ListItem extends BI.BasicButton {
    static xtype = 'dec.dcm.connection.list_item';

    props = {
        name: '',
        creator: '',
        databaseType: '',
        height: 25,
        baseCls: 'dec-dcm-connection-list-item bi-list-item-active2',
        $testId: 'dec-dcm-connection-list-item',
    };

    store: ListItemModel['store'];
    model: ListItemModel['model'];

    nameLabel: Label;
    nameEditor: SignEditor;
    downListCombo: DownListCombo;

    watch = {
        isEdit: (isEdit: boolean) => {
            this.nameLabel.setVisible(!isEdit);
            this.nameEditor.setVisible(isEdit);
            if (isEdit) {
                this.nameEditor.focus();
            }
        },
    };

    render() {
        const { name, databaseType } = this.options;

        return {
            type: BI.HTapeLayout.xtype,
            $scope: name,
            items: [{
                el: {
                    type: BI.IconLabel.xtype,
                    cls: 'dcm-link-font icon-size-16',
                    title: name,
                },
                width: 25,
            }, {
                type: BI.VerticalLayout.xtype,
                items: [
                    {
                        type: BI.Label.xtype,
                        text: name,
                        textAlign: 'left',
                        height: 25,
                        title: name,
                        ref: (_ref: Label) => {
                            this.nameLabel = _ref;
                        },
                    },
                    {
                        type: BI.SignEditor.xtype,
                        $value: 'connection-name',
                        value: name,
                        invisible: !this.model.isEdit,
                        ref: (_ref: SignEditor) => {
                            this.nameEditor = _ref;
                        },
                        listeners: [{
                            eventName: BI.SignEditor.EVENT_BLUR,
                            action: () => {
                                const newName = this.nameEditor.getValue();
                                if (getChartLength(newName) > 200) {
                                    BI.Msg.toast(BI.i18nText(BI.i18nText('Dec-Dcm_Connection_Cannot_Too_Lang')), {
                                        level: 'error',
                                    });
                                    this.store.setIsEdit(false, name);
                                    this.nameLabel.setText(name);
                                    this.nameEditor.setValue(name);

                                    return;
                                }
                                this.store.changeName(name, newName).then(re => {
                                    this.store.setIsEdit(false, name);
                                    if (re.errorCode) {
                                        BI.Msg.toast(BI.i18nText(re.errorMsg), {
                                            level: 'error',
                                        });
                                        this.nameLabel.setText(name);
                                        this.nameEditor.setValue(name);
                                    } else {
                                        this.nameLabel.setText(newName);
                                    }
                                });
                            },
                        }],
                    },
                ],
            }, {
                el: databaseType ? {
                    type: BI.DownListCombo.xtype,
                    cls: 'link-item-icon',
                    stopPropagation: true,
                    hgap: 8,
                    el: {
                        type: BI.IconButton.xtype,
                        $value: 'other-edit',
                        cls: 'dcm-link-other-font icon-size-16',
                    },
                    items: this.renderDownList(),
                    ref: (_ref: DownListCombo) => {
                        this.downListCombo = _ref;
                    },
                    listeners: [{
                        eventName: BI.DownListCombo.EVENT_CHANGE,
                        action: (value: string) => {
                            this.itemActionCalculate().actionClac(value);
                        },
                    }, {
                        eventName: BI.DownListCombo.EVENT_BEFORE_POPUPVIEW,
                        action: () => {
                            this.downListCombo.setValue('');
                        },
                    }],

                } : {
                    type: BI.Layout.xtype,
                },
                width: 25,
            }],
        };
    }

    private renderDownList() {
        const { creator, databaseType, name } = this.options;
        const canEdit = connectionCanEdit(this.model.connections.find(item => item.connectionName === name));
        const isRegistered = hasRegistered(databaseType);
        const otherIcons = [
            {
                text: BI.i18nText('Dec-Dcm_Type', getTextByDatabaseType(databaseType)),
                disabled: true,
                cls: 'dcm-info-font',
                value: 12,
            },
            {
                text: BI.i18nText('Dec-Dcm_Creator', creator),
                disabled: true,
                value: 12,
            },
        ];
        if (!isRegistered) {
            return [otherIcons];
        }

        return [
            [
                {
                    text: BI.i18nText('Dec-Dcm_Test_Connection'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-test-font',
                    value: 'test',
                },
                {
                    text: BI.i18nText('Dec-Dcm_Edit'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-link-edit-font',
                    value: 'edit',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Change_Name'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-change-name-font',
                    value: 'changeName',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Copy'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'copy-font',
                    value: 'copy',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Delete'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-delete-font',
                    value: 'delete',
                    invisible: !canEdit,
                    bubble: BI.i18nText('Dec-Dcm_Connection_Make_Sure_Delete'),
                },
            ],
            otherIcons,
        ];
    }

    doClick() {
        const { name } = this.options;
        this.store.setConnectionSelected(name);
    }

    private testConnectionAction() {
        const { name } = this.options;
        testConnection(this.model.connections.find(item => item.connectionName === name));
    }

    private itemActionCalculate() {
        const { name } = this.options;
        const actionsMap = {
            test: this.testConnectionAction.bind(this),
            edit: () => {
                this.store.setConnectionSelected(name);
                this.store.getConnectionStatus().then(re => {
                    this.store.setPageIndex(PAGE_INDEX.MAINTAIN);
                    this.store.setDatebaseTypeSelected('');
                })
                    .catch(() => {
                    });
            },
            changeName: () => {
                this.store.setIsEdit(true, name);
            },
            copy: () => {
                this.store.copyConnection(name);
            },
            delete: () => {
                this.store.deleteConnection(name);
            },
        };

        return {
            actionClac: (name: string) => actionsMap[name] && actionsMap[name](),
        };
    }
}

==> 11.0.tar.gz: decision-webui-dcm/src/modules/pages/connection/list/list_item/list_item.ts <==
import { shortcut, store } from '@core/core';
import './list_item.less';
import { ListItemModel } from './list_item.model';
import { PAGE_INDEX } from '@constants/constant';
import { hasRegistered } from '../list.service';
import { connectionCanEdit, getTextByDatabaseType, getChartLength } from '../../../../app.service';
import { testConnection } from '../../../maintain/forms/form.server';
import { DownListCombo, Label, SignEditor } from '@fui/core';
import { ApiFactory } from '../../../../crud/apiFactory';
import { checkIllegalStrings } from "@core/index";

const api = new ApiFactory().create();

@shortcut()
@store(ListItemModel)
export class ListItem extends BI.BasicButton {
    static xtype = 'dec.dcm.connection.list_item';

    props = {
        name: '',
        creator: '',
        databaseType: '',
        pluginConnection: false,
        height: 25,
        baseCls: 'dec-dcm-connection-list-item bi-list-item-active2',
        $testId: 'dec-dcm-connection-list-item',
    };

    store: ListItemModel['store'];
    model: ListItemModel['model'];

    nameLabel: Label;
    nameEditor: SignEditor;
    downListCombo: DownListCombo;

    watch = {
        isEdit: (isEdit: boolean) => {
            this.nameLabel.setVisible(!isEdit);
            this.nameEditor.setVisible(isEdit);
            if (isEdit) {
                this.nameEditor.focus();
            }
        },
    };

    render() {
        const { name, databaseType, pluginConnection } = this.options;

        return {
            type: BI.HTapeLayout.xtype,
            $scope: name,
            items: [{
                el: {
                    type: BI.IconLabel.xtype,
                    cls: 'dcm-link-font icon-size-16',
                    title: name,
                },
                width: 25,
            }, {
                type: BI.VerticalLayout.xtype,
                items: [
                    {
                        type: BI.Label.xtype,
                        text: name,
                        textAlign: 'left',
                        height: 25,
                        title: name,
                        ref: (_ref: Label) => {
                            this.nameLabel = _ref;
                        },
                    },
                    {
                        type: BI.SignEditor.xtype,
                        $value: 'connection-name',
                        value: name,
                        invisible: !this.model.isEdit,
                        ref: (_ref: SignEditor) => {
                            this.nameEditor = _ref;
                        },
                        listeners: [{
                            eventName: BI.SignEditor.EVENT_BLUR,
                            action: () => {
                                const newName = this.nameEditor.getValue();
                                if (getChartLength(newName) > 200) {
                                    BI.Msg.toast(BI.i18nText(BI.i18nText('Dec-Dcm_Connection_Cannot_Too_Lang')), {
                                        level: 'error',
                                    });
                                    this.store.setIsEdit(false, name);
                                    this.nameLabel.setText(name);
                                    this.nameEditor.setValue(name);

                                    return;
                                }
                                const result = checkIllegalStrings(newName);
                                if (!result.legal) {
                                    BI.Msg.toast(result.errorMsg, {
                                        level: 'error',
                                    });
                                    this.store.setIsEdit(false, name);
                                    this.nameLabel.setText(name);
                                    this.nameEditor.setValue(name);

                                    return;
                                }
                                this.store.changeName(name, newName).then(re => {
                                    this.store.setIsEdit(false, name);
                                    if (re.errorCode) {
                                        BI.Msg.toast(BI.i18nText(re.errorMsg), {
                                            level: 'error',
                                        });
                                        this.nameLabel.setText(name);
                                        this.nameEditor.setValue(name);
                                    } else {
                                        this.nameLabel.setText(newName);
                                    }
                                });
                            },
                        }],
                    },
                ],
            }, {
                el: databaseType && !pluginConnection ? {
                    type: BI.DownListCombo.xtype,
                    cls: 'link-item-icon',
                    stopPropagation: true,
                    hgap: 8,
                    el: {
                        type: BI.IconButton.xtype,
                        $value: 'other-edit',
                        cls: 'dcm-link-other-font icon-size-16',
                    },
                    items: this.renderDownList(),
                    ref: (_ref: DownListCombo) => {
                        this.downListCombo = _ref;
                    },
                    listeners: [{
                        eventName: BI.DownListCombo.EVENT_CHANGE,
                        action: (value: string) => {
                            this.itemActionCalculate().actionClac(value);
                        },
                    }, {
                        eventName: BI.DownListCombo.EVENT_BEFORE_POPUPVIEW,
                        action: () => {
                            this.downListCombo.setValue('');
                        },
                    }],

                } : {
                    type: BI.Layout.xtype,
                },
                width: 25,
            }],
        };
    }

    private renderDownList() {
        const { creator, databaseType, name } = this.options;
        const canEdit = connectionCanEdit(this.model.connections.find(item => item.connectionName === name));
        const isRegistered = hasRegistered(databaseType);
        const otherIcons = [
            {
                text: BI.i18nText('Dec-Dcm_Type', getTextByDatabaseType(databaseType)),
                disabled: true,
                cls: 'dcm-info-font',
                value: 12,
            },
            {
                text: BI.i18nText('Dec-Dcm_Creator', creator),
                disabled: true,
                value: 12,
            },
        ];
        if (!isRegistered) {
            return [otherIcons];
        }

        return [
            [
                {
                    text: BI.i18nText('Dec-Dcm_Test_Connection'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-test-font',
                    value: 'test',
                },
                {
                    text: BI.i18nText('Dec-Dcm_Edit'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-link-edit-font',
                    value: 'edit',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Change_Name'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-change-name-font',
                    value: 'changeName',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Copy'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'copy-font',
                    value: 'copy',
                    invisible: !canEdit,
                },
                {
                    text: BI.i18nText('Dec-Dcm_Delete'),
                    $testId: 'dec-dcm-connection-list-btn',
                    cls: 'dcm-delete-font',
                    value: 'delete',
                    invisible: !canEdit,
                    bubble: BI.i18nText('Dec-Dcm_Connection_Make_Sure_Delete'),
                },
            ],
            otherIcons,
        ];
    }

    doClick() {
        const { name } = this.options;
        this.store.setConnectionSelected(name);
    }

    private testConnectionAction() {
        // 接口返回的内容是对称加密的，前端要先解密再用新加密传回去
        const connection = BI.cloneDeep(this.model.connections
            .find(item => item.connectionName === this.options.name));

        if (BI.isNull(connection)) return;

        const validationQuery = connection?.connectionData?.connectionPoolAttr?.validationQuery || '';

        BI.set(connection, 'connectionData.connectionPoolAttr.validationQuery', api.getCipher(api.getPlain(validationQuery)));

        testConnection(connection);
    }

    private itemActionCalculate() {
        const { name } = this.options;
        const actionsMap = {
            test: this.testConnectionAction.bind(this),
            edit: () => {
                this.store.setConnectionSelected(name);
                this.store.getConnectionStatus().then(re => {
                    this.store.setPageIndex(PAGE_INDEX.MAINTAIN);
                    this.store.setDatebaseTypeSelected('');
                })
                    .catch(() => {
                    });
            },
            changeName: () => {
                this.store.setIsEdit(true, name);
            },
            copy: () => {
                this.store.copyConnection(name);
            },
            delete: () => {
                this.store.deleteConnection(name);
            },
        };

        return {
            actionClac: (name: string) => actionsMap[name] && actionsMap[name](),
        };
    }
}
